@@ -4,7 +4,7 @@ use warnings;
 use strict;
 use Carp;
 
-our $VERSION = 'v2.0.0';
+our $VERSION = 'v2.0.1';
 
 
 # Possible types of current directory:
@@ -44,7 +44,7 @@ Narada - framework for ease deploy and support microservice projects
 
 =head1 VERSION
 
-This document describes Narada version v2.0.0
+This document describes Narada version v2.0.1
 
 
 =head1 SYNOPSIS
@@ -630,6 +630,22 @@ using upgrade operations in this file when describing upgrade from version
 Narada uses L<App::migrate> to implement project migrations, format of
 C<.migrate> files is documented in L<App::migrate/"SYNTAX">.
 
+=over
+
+B<When you need to convert some data in files or database when installing
+new version you should use> C<.migrate> B<file to run scripts which will
+do this.>
+
+You should not try to do these data migrations automatically on first time
+new version of your project's application starts - both because this will
+make impossible to downgrade quickly and without losing data (if you'll
+provide script which does backward data conversion, of course) and you'll
+have to restore from backup instead, and because project migration may
+include many upgrades at once and your application as it was at one of
+intermediate versions wasn't get a chance to run at all.
+
+=back
+
 =back
 
 =head2 Backup
